#include "GamePlayScene.h"


USING_NS_CC;

Scene* GamePlayScene::createScene()
{
	auto scene = Scene::createWithPhysics();
	//scene->getPhysicsWorld()->setDebugDrawMask(PhysicsWorld::DEBUGDRAW_ALL);
	scene->getPhysicsWorld()->setGravity(Vec2(0, 0));
	
	auto layer = GamePlayScene::create();
	layer->setPhysicsWorld(scene->getPhysicsWorld());


	scene->addChild(layer);
	
	return scene;
}


bool GamePlayScene::init()
{
	if (!Layer::init())
	{
		return false;
	}

	


	auto edgeBody = PhysicsBody::createEdgeBox(visibleSize, PHYSICSBODY_MATERIAL_DEFAULT, 3);

	auto edgeNode = Node::create();
	edgeNode->setPosition(Vec2(visibleSize.width / 2, visibleSize.height / 2));
	edgeNode->setPhysicsBody(edgeBody);
	this->addChild(edgeNode);


	auto bg = Sprite::create("bg.png");
	bg->setPosition(Vec2(visibleSize.width / 2, visibleSize.height / 2));
	this->addChild(bg, 0);

	plane->setPosition(Vec2(visibleSize.width / 2, visibleSize.height / 2 + 200));
	spriteBody = PhysicsBody::createBox(plane->getContentSize(), PhysicsMaterial(1, 1, 1));
	spriteBody->setCollisionBitmask(1);
	plane->setPhysicsBody(spriteBody);
	spriteBody->setContactTestBitmask(true);
		
	this->addChild(plane, 1);

	
	
	


	auto listener = EventListenerTouchOneByOne::create();
	listener->setSwallowTouches(true);
	listener->onTouchBegan = CC_CALLBACK_2(GamePlayScene::onTouchBegan, this);
	listener->onTouchMoved = CC_CALLBACK_2(GamePlayScene::onTouchMoved, this);
	listener->onTouchEnded = CC_CALLBACK_2(GamePlayScene::onTouchEnded, this);
	
	_eventDispatcher->addEventListenerWithSceneGraphPriority(listener, this);

	auto contactListener = EventListenerPhysicsContact::create();
	contactListener->onContactBegin = CC_CALLBACK_1(GamePlayScene::onContactBegin, this);
	this->getEventDispatcher()->addEventListenerWithSceneGraphPriority(contactListener, this);


	this->schedule(schedule_selector(GamePlayScene::SpawnLitter),1);

	scheduleUpdate();
	

	return true;
}

bool GamePlayScene::onContactBegin(cocos2d::PhysicsContact &contact)
{
	PhysicsBody *a = contact.getShapeA()->getBody();
	PhysicsBody *b = contact.getShapeB()->getBody();

	if ((1 == a->getCollisionBitmask() && 2 == b->getCollisionBitmask()) || (2 == a->getCollisionBitmask() && 1 == b->getCollisionBitmask()))
	{
		CCLOG("Collision Has Occured");
	}

	return true;
}


bool GamePlayScene::onTouchBegan(Touch* touch, Event* event)
{
	CCLOG("onTouchBegan x = %f, y = %f", touch->getLocation().x, touch->getLocation().y);
	
	bTouch = true;

	return true;	
}
void GamePlayScene::onTouchMoved(Touch* touch, Event* event)
{
	CCLOG("onTouchMoved x = %f, y = %f", touch->getLocation().x, touch->getLocation().y);

	
}
void GamePlayScene::onTouchEnded(Touch* touch, Event* event)
{
	CCLOG("onTouchEnded x = %f, y = %f", touch->getLocation().x, touch->getLocation().x);

	bTouch = false;	

} 

void GamePlayScene::update(float dt)
{

	if (bTouch == true)
	{
		plane->setPositionX(visibleSize.width / 2 + origin.x);
		plane->setPositionY(plane->getPositionY() + (0.00375 * visibleSize.height));
	}

	else
	{
		plane->setPositionX(visibleSize.width / 2 + origin.x);
		plane->setPositionY(plane->getPositionY() - (0.00375 * visibleSize.height));	
	}


}

void GamePlayScene::SpawnLitter(float dt)
{
	litter_1.moveLitter();
	CCLOG("Litter Spawned");

}